summaryrefslogtreecommitdiffstats
path: root/tdecore/network
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:33:40 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-01 13:33:40 -0600
commit4fb897b216c41c13f128c71bcc66f60e2dc601c4 (patch)
tree2891b54cd6ec39db133da0110028ec93fc006751 /tdecore/network
parent8fc8811ef6079a15decd33f1ea5d95dd718e4557 (diff)
downloadtdelibs-4fb897b216c41c13f128c71bcc66f60e2dc601c4.tar.gz
tdelibs-4fb897b216c41c13f128c71bcc66f60e2dc601c4.zip
Rename additional global TQt functions
Diffstat (limited to 'tdecore/network')
-rw-r--r--tdecore/network/khttpproxysocketdevice.cpp8
-rw-r--r--tdecore/network/kresolvermanager.cpp18
-rw-r--r--tdecore/network/kresolverstandardworkers.cpp16
3 files changed, 21 insertions, 21 deletions
diff --git a/tdecore/network/khttpproxysocketdevice.cpp b/tdecore/network/khttpproxysocketdevice.cpp
index 15a7482ad..42d65326b 100644
--- a/tdecore/network/khttpproxysocketdevice.cpp
+++ b/tdecore/network/khttpproxysocketdevice.cpp
@@ -182,12 +182,12 @@ bool KHttpProxySocketDevice::parseServerReply()
TQ_LONG written = tqwriteBlock(d->request, d->request.length());
if (written < 0)
{
- qDebug("KHttpProxySocketDevice: would block writing request!");
+ tqDebug("KHttpProxySocketDevice: would block writing request!");
if (error() == WouldBlock)
setError(IO_ConnectError, InProgress);
return error() == WouldBlock; // error
}
- qDebug("KHttpProxySocketDevice: request written");
+ tqDebug("KHttpProxySocketDevice: request written");
d->request.remove(0, written);
@@ -206,7 +206,7 @@ bool KHttpProxySocketDevice::parseServerReply()
if (!blocking())
{
TQ_LONG avail = bytesAvailable();
- qDebug("KHttpProxySocketDevice: %ld bytes available", avail);
+ tqDebug("KHttpProxySocketDevice: %ld bytes available", avail);
setState(0);
if (avail == 0)
{
@@ -264,7 +264,7 @@ bool KHttpProxySocketDevice::parseServerReply()
}
// now really parse the reply
- qDebug("KHttpProxySocketDevice: get reply: %s\n",
+ tqDebug("KHttpProxySocketDevice: get reply: %s\n",
d->reply.left(d->reply.find('\r')).data());
if (d->reply.left(7) != "HTTP/1." ||
(index = d->reply.find(' ')) == -1 ||
diff --git a/tdecore/network/kresolvermanager.cpp b/tdecore/network/kresolvermanager.cpp
index b3c7172ae..7801a4295 100644
--- a/tdecore/network/kresolvermanager.cpp
+++ b/tdecore/network/kresolvermanager.cpp
@@ -207,7 +207,7 @@ public:
// other threads are already using the API, so wait till
// it's all clear
// the thread that emits this condition will also call res_init
- //qDebug("ResInitUsage: waiting for libresolv to be clear");
+ //tqDebug("ResInitUsage: waiting for libresolv to be clear");
cond.wait(&mutex);
}
else
@@ -264,12 +264,12 @@ void KResolverThread::run()
// initialisation
// enter the loop already
- //qDebug("KResolverThread(thread %u/%p): started", pid, (void*)TQThread::currentThread());
+ //tqDebug("KResolverThread(thread %u/%p): started", pid, (void*)TQThread::currentThread());
KResolverManager::manager()->registerThread(this);
while (true)
{
data = KResolverManager::manager()->requestData(this, ::maxThreadWaitTime);
- //qDebug("KResolverThread(thread %u/%p) got data %p", KResolverManager::pid,
+ //tqDebug("KResolverThread(thread %u/%p) got data %p", KResolverManager::pid,
// (void*)TQThread::currentThread(), (void*)data);
if (data)
{
@@ -292,7 +292,7 @@ void KResolverThread::run()
}
KResolverManager::manager()->unregisterThread(this);
- //qDebug("KResolverThread(thread %u/%p): exiting", pid, (void*)TQThread::currentThread());
+ //tqDebug("KResolverThread(thread %u/%p): exiting", pid, (void*)TQThread::currentThread());
}
bool KResolverThread::checkResolver()
@@ -415,7 +415,7 @@ void KResolverManager::releaseData(KResolverThread *, RequestData* data)
// This function is called in a worker thread!!
/////
- //qDebug("KResolverManager::releaseData(%u/%p): %p has been released", pid,
+ //tqDebug("KResolverManager::releaseData(%u/%p): %p has been released", pid,
// (void*)TQThread::currentThread(), (void*)data);
if (data->obj)
@@ -460,7 +460,7 @@ void KResolverManager::handleFinished()
curr = currentRequests.prev();
}
- //qDebug("KResolverManager::handleFinished(%u): %d requests to notify", pid, doneRequests.count());
+ //tqDebug("KResolverManager::handleFinished(%u): %d requests to notify", pid, doneRequests.count());
while (RequestData *d = doneRequests.dequeue())
doNotifying(d);
@@ -468,7 +468,7 @@ void KResolverManager::handleFinished()
if (redo)
{
- //qDebug("KResolverManager::handleFinished(%u): restarting processing to catch requestor",
+ //tqDebug("KResolverManager::handleFinished(%u): restarting processing to catch requestor",
// pid);
handleFinished();
}
@@ -490,7 +490,7 @@ bool KResolverManager::handleFinishedItem(RequestData* curr)
if (curr->requestor)
--curr->requestor->nRequests;
- //qDebug("KResolverManager::handleFinishedItem(%u): removing %p since it's done",
+ //tqDebug("KResolverManager::handleFinishedItem(%u): removing %p since it's done",
// pid, (void*)curr);
return true;
}
@@ -600,7 +600,7 @@ void KResolverManager::doNotifying(RequestData *p)
// reset address
r.setAddress(p->input->node, p->input->service);
- //qDebug("KResolverManager::doNotifying(%u/%p): for %p whose status is %d and has %d results",
+ //tqDebug("KResolverManager::doNotifying(%u/%p): for %p whose status is %d and has %d results",
//pid, (void*)TQThread::currentThread(), (void*)p, p->obj->status, r.count());
p->obj->errorcode = r.error();
diff --git a/tdecore/network/kresolverstandardworkers.cpp b/tdecore/network/kresolverstandardworkers.cpp
index a295335b5..5f0229969 100644
--- a/tdecore/network/kresolverstandardworkers.cpp
+++ b/tdecore/network/kresolverstandardworkers.cpp
@@ -240,7 +240,7 @@ namespace
int my_h_errno;
char *buf = 0L;
// qDebug("ResolveThread::run(): started threaded gethostbyname for %s (af = %d)",
// m_hostname.data(), m_af);
ResolverLocker resLock( this );
@@ -287,7 +287,7 @@ namespace
if (resultptr != 0L)
my_h_errno = 0;
// qDebug("GetHostByNameThread::run(): gethostbyname for %s (af = %d) returned: %d",
// m_hostname.data(), m_af, my_h_errno);
if (res == ERANGE)
@@ -317,7 +317,7 @@ namespace
{
if (herrno)
{
- qDebug("KStandardWorker::processResults: got error %d", herrno);
+ tqDebug("KStandardWorker::processResults: got error %d", herrno);
switch (herrno)
{
case HOST_NOT_FOUND:
@@ -368,9 +368,9 @@ namespace
{
sa.setHost(KIpAddress(he->h_addr_list[i], he->h_addrtype == AF_INET ? 4 : 6));
results.prepend(KResolverEntry(sa, socktype, proto, canon, m_hostname));
- // qDebug("KStandardWorker::processResults: adding %s", sa.toString().latin1());
+ // tqDebug("KStandardWorker::processResults: adding %s", sa.toString().latin1());
}
- // qDebug("KStandardWorker::processResults: added %d entries", i);
+ // tqDebug("KStandardWorker::processResults: added %d entries", i);
}
#else // HAVE_GETADDRINFO
@@ -559,12 +559,12 @@ bool KStandardWorker::sanityCheck()
if (m_encodedName.isNull())
{
- qDebug("could not encode hostname '%s' (UTF-8)", node.utf8().data());
+ tqDebug("could not encode hostname '%s' (UTF-8)", node.utf8().data());
setError(KResolver::NoName);
return false; // invalid hostname!
}
- // qDebug("Using encoded hostname '%s' for '%s' (UTF-8)", m_encodedName.data(),
+ // tqDebug("Using encoded hostname '%s' for '%s' (UTF-8)", m_encodedName.data(),
// node.utf8().data());
}
}
@@ -679,7 +679,7 @@ KResolver::ErrorCodes KStandardWorker::addUnix()
// put it in /tmp
pathname.prepend("/tmp/");
- // qDebug("QNoResolveWorker::addUnix(): adding Unix socket for %s", pathname.local8Bit().data());
+ // tqDebug("QNoResolveWorker::addUnix(): adding Unix socket for %s", pathname.local8Bit().data());
KUnixSocketAddress sa(pathname);
int socktype = socketType();
if (socktype == 0)
@@ -240,7 +240,7 @@ namespace
int my_h_errno;
char *buf = 0L;
- // qDebug("ResolveThread::run(): started threaded gethostbyname for %s (af = %d)",
+ // tqDebug("ResolveThread::run(): started threaded gethostbyname for %s (af = %d)",
// m_hostname.data(), m_af);
ResolverLocker resLock( this );
@@ -287,7 +287,7 @@ namespace
if (resultptr != 0L)
my_h_errno = 0;
- // qDebug("GetHostByNameThread::run(): gethostbyname for %s (af = %d) returned: %d",
+ // tqDebug("GetHostByNameThread::run(): gethostbyname for %s (af = %d) returned: %d",
// m_hostname.data(), m_af, my_h_errno);
if (res == ERANGE)